@@ -1,10 +1,19 @@
+# flake8: noqa
 import inspect
 import logging
 import traceback
 
 import pkg_resources
 
-from featuretools.primitives.api import *  # noqa: F403
+from featuretools.primitives.standard import *
+from featuretools.primitives.utils import (
+    get_aggregation_primitives,
+    get_default_aggregation_primitives,
+    get_default_transform_primitives,
+    get_transform_primitives,
+    list_primitives,
+    summarize_primitives,
+)
 
 
 def _load_primitives():
