@@ -6,8 +6,7 @@ from pympler.asizeof import asizeof
 from woodwork.column_schema import ColumnSchema
 from woodwork.logical_types import Datetime, Integer
 
-import featuretools as ft
-from featuretools import config
+from featuretools import Feature, config, feature_base
 from featuretools.feature_base import IdentityFeature
 from featuretools.primitives import (
     Count,
@@ -24,22 +23,24 @@ from featuretools.tests.testing_utils import check_rename
 
 
 def test_copy_features_does_not_copy_entityset(es):
-    agg = ft.Feature(
-        es["log"].ww["value"], parent_dataframe_name="sessions", primitive=Sum
+    agg = Feature(
+        es["log"].ww["value"],
+        parent_dataframe_name="sessions",
+        primitive=Sum,
     )
-    agg_where = ft.Feature(
+    agg_where = Feature(
         es["log"].ww["value"],
         parent_dataframe_name="sessions",
         where=IdentityFeature(es["log"].ww["value"]) == 2,
         primitive=Sum,
     )
-    agg_use_previous = ft.Feature(
+    agg_use_previous = Feature(
         es["log"].ww["value"],
         parent_dataframe_name="sessions",
         use_previous="4 days",
         primitive=Sum,
     )
-    agg_use_previous_where = ft.Feature(
+    agg_use_previous_where = Feature(
         es["log"].ww["value"],
         parent_dataframe_name="sessions",
         where=IdentityFeature(es["log"].ww["value"]) == 2,
@@ -54,10 +55,10 @@ def test_copy_features_does_not_copy_entityset(es):
 
 
 def test_get_dependencies(es):
-    f = ft.Feature(es["log"].ww["value"])
-    agg1 = ft.Feature(f, parent_dataframe_name="sessions", primitive=Sum)
-    agg2 = ft.Feature(agg1, parent_dataframe_name="customers", primitive=Sum)
-    d1 = ft.Feature(agg2, "sessions")
+    f = Feature(es["log"].ww["value"])
+    agg1 = Feature(f, parent_dataframe_name="sessions", primitive=Sum)
+    agg2 = Feature(agg1, parent_dataframe_name="customers", primitive=Sum)
+    d1 = Feature(agg2, "sessions")
     shallow = d1.get_dependencies(deep=False, ignored=None)
     deep = d1.get_dependencies(deep=True, ignored=None)
     ignored = set([agg1.unique_name()])
@@ -72,12 +73,12 @@ def test_get_dependencies(es):
 
 
 def test_get_depth(es):
-    f = ft.Feature(es["log"].ww["value"])
-    g = ft.Feature(es["log"].ww["value"])
-    agg1 = ft.Feature(f, parent_dataframe_name="sessions", primitive=Last)
-    agg2 = ft.Feature(agg1, parent_dataframe_name="customers", primitive=Last)
-    d1 = ft.Feature(agg2, "sessions")
-    d2 = ft.Feature(d1, "log")
+    f = Feature(es["log"].ww["value"])
+    g = Feature(es["log"].ww["value"])
+    agg1 = Feature(f, parent_dataframe_name="sessions", primitive=Last)
+    agg2 = Feature(agg1, parent_dataframe_name="customers", primitive=Last)
+    d1 = Feature(agg2, "sessions")
+    d2 = Feature(d1, "log")
     assert d2.get_depth() == 4
     # Make sure this works if we pass in two of the same
     # feature. This came up when user supplied duplicates
@@ -91,7 +92,7 @@ def test_get_depth(es):
 
 
 def test_squared(es):
-    feature = ft.Feature(es["log"].ww["value"])
+    feature = Feature(es["log"].ww["value"])
     squared = feature * feature
     assert len(squared.base_features) == 2
     assert (
@@ -100,7 +101,7 @@ def test_squared(es):
 
 
 def test_return_type_inference(es):
-    mode = ft.Feature(
+    mode = Feature(
         es["log"].ww["priority_level"],
         parent_dataframe_name="customers",
         primitive=Mode,
@@ -112,12 +113,12 @@ def test_return_type_inference(es):
 
 
 def test_return_type_inference_direct_feature(es):
-    mode = ft.Feature(
+    mode = Feature(
         es["log"].ww["priority_level"],
         parent_dataframe_name="customers",
         primitive=Mode,
     )
-    mode_session = ft.Feature(mode, "sessions")
+    mode_session = Feature(mode, "sessions")
     assert (
         mode_session.column_schema
         == IdentityFeature(es["log"].ww["priority_level"]).column_schema
@@ -125,41 +126,49 @@ def test_return_type_inference_direct_feature(es):
 
 
 def test_return_type_inference_index(es):
-    last = ft.Feature(
-        es["log"].ww["id"], parent_dataframe_name="customers", primitive=Last
+    last = Feature(
+        es["log"].ww["id"],
+        parent_dataframe_name="customers",
+        primitive=Last,
     )
     assert "index" not in last.column_schema.semantic_tags
     assert isinstance(last.column_schema.logical_type, Integer)
 
 
 def test_return_type_inference_datetime_time_index(es):
-    last = ft.Feature(
-        es["log"].ww["datetime"], parent_dataframe_name="customers", primitive=Last
+    last = Feature(
+        es["log"].ww["datetime"],
+        parent_dataframe_name="customers",
+        primitive=Last,
     )
     assert isinstance(last.column_schema.logical_type, Datetime)
 
 
 def test_return_type_inference_numeric_time_index(int_es):
-    last = ft.Feature(
-        int_es["log"].ww["datetime"], parent_dataframe_name="customers", primitive=Last
+    last = Feature(
+        int_es["log"].ww["datetime"],
+        parent_dataframe_name="customers",
+        primitive=Last,
     )
     assert "numeric" in last.column_schema.semantic_tags
 
 
 def test_return_type_inference_id(es):
     # direct features should keep foreign key tag
-    direct_id_feature = ft.Feature(es["sessions"].ww["customer_id"], "log")
+    direct_id_feature = Feature(es["sessions"].ww["customer_id"], "log")
     assert "foreign_key" in direct_id_feature.column_schema.semantic_tags
 
     # aggregations of foreign key types should get converted
-    last_feat = ft.Feature(
-        es["log"].ww["session_id"], parent_dataframe_name="customers", primitive=Last
+    last_feat = Feature(
+        es["log"].ww["session_id"],
+        parent_dataframe_name="customers",
+        primitive=Last,
     )
     assert "foreign_key" not in last_feat.column_schema.semantic_tags
     assert isinstance(last_feat.column_schema.logical_type, Integer)
 
     # also test direct feature of aggregation
-    last_direct = ft.Feature(last_feat, "sessions")
+    last_direct = Feature(last_feat, "sessions")
     assert "foreign_key" not in last_direct.column_schema.semantic_tags
     assert isinstance(last_direct.column_schema.logical_type, Integer)
 
@@ -195,8 +204,9 @@ def test_set_data_path(es):
 
 
 def test_to_dictionary_direct(es):
-    actual = ft.Feature(
-        IdentityFeature(es["sessions"].ww["customer_id"]), "log"
+    actual = Feature(
+        IdentityFeature(es["sessions"].ww["customer_id"]),
+        "log",
     ).to_dictionary()
 
     expected = {
@@ -218,7 +228,7 @@ def test_to_dictionary_direct(es):
 
 
 def test_to_dictionary_identity(es):
-    actual = ft.Feature(es["sessions"].ww["customer_id"]).to_dictionary()
+    actual = Feature(es["sessions"].ww["customer_id"]).to_dictionary()
 
     expected = {
         "type": "IdentityFeature",
@@ -235,8 +245,10 @@ def test_to_dictionary_identity(es):
 
 def test_to_dictionary_agg(es):
     primitive = Sum()
-    actual = ft.Feature(
-        es["customers"].ww["age"], primitive=primitive, parent_dataframe_name="cohorts"
+    actual = Feature(
+        es["customers"].ww["age"],
+        primitive=primitive,
+        parent_dataframe_name="cohorts",
     ).to_dictionary()
 
     expected = {
@@ -251,7 +263,7 @@ def test_to_dictionary_agg(es):
                     "child_dataframe_name": "customers",
                     "parent_column_name": "cohort",
                     "child_column_name": "cohort",
-                }
+                },
             ],
             "primitive": primitive,
             "where": None,
@@ -264,10 +276,10 @@ def test_to_dictionary_agg(es):
 
 def test_to_dictionary_where(es):
     primitive = Sum()
-    actual = ft.Feature(
+    actual = Feature(
         es["log"].ww["value"],
         parent_dataframe_name="sessions",
-        where=ft.IdentityFeature(es["log"].ww["value"]) == 2,
+        where=IdentityFeature(es["log"].ww["value"]) == 2,
         primitive=primitive,
     ).to_dictionary()
 
@@ -283,7 +295,7 @@ def test_to_dictionary_where(es):
                     "child_dataframe_name": "log",
                     "parent_column_name": "id",
                     "child_column_name": "session_id",
-                }
+                },
             ],
             "primitive": primitive,
             "where": "log: value = 2",
@@ -296,7 +308,7 @@ def test_to_dictionary_where(es):
 
 def test_to_dictionary_trans(es):
     primitive = Negate()
-    trans_feature = ft.Feature(es["customers"].ww["age"], primitive=primitive)
+    trans_feature = Feature(es["customers"].ww["age"], primitive=primitive)
 
     expected = {
         "type": "TransformFeature",
@@ -313,9 +325,11 @@ def test_to_dictionary_trans(es):
 
 def test_to_dictionary_groupby_trans(es):
     primitive = Negate()
-    id_feat = ft.Feature(es["log"].ww["product_id"])
-    groupby_feature = ft.Feature(
-        es["log"].ww["value"], primitive=primitive, groupby=id_feat
+    id_feat = Feature(es["log"].ww["product_id"])
+    groupby_feature = Feature(
+        es["log"].ww["value"],
+        primitive=primitive,
+        groupby=id_feat,
     )
 
     expected = {
@@ -333,7 +347,7 @@ def test_to_dictionary_groupby_trans(es):
 
 
 def test_to_dictionary_multi_slice(es):
-    slice_feature = ft.Feature(
+    slice_feature = Feature(
         es["log"].ww["product_id"],
         parent_dataframe_name="customers",
         primitive=NMostCommon(n=2),
@@ -354,14 +368,14 @@ def test_to_dictionary_multi_slice(es):
 
 def test_multi_output_base_error_agg(es):
     three_common = NMostCommon(3)
-    tc = ft.Feature(
+    tc = Feature(
         es["log"].ww["product_id"],
         parent_dataframe_name="sessions",
         primitive=three_common,
     )
     error_text = "Cannot stack on whole multi-output feature."
     with pytest.raises(ValueError, match=error_text):
-        ft.Feature(tc, parent_dataframe_name="customers", primitive=NumUnique)
+        Feature(tc, parent_dataframe_name="customers", primitive=NumUnique)
 
 
 def test_multi_output_base_error_trans(es):
@@ -371,15 +385,15 @@ def test_multi_output_base_error_trans(es):
         return_type = ColumnSchema(semantic_tags={"numeric"})
         number_output_features = 6
 
-    tc = ft.Feature(es["customers"].ww["birthday"], primitive=TestTime)
+    tc = Feature(es["customers"].ww["birthday"], primitive=TestTime)
 
     error_text = "Cannot stack on whole multi-output feature."
     with pytest.raises(ValueError, match=error_text):
-        ft.Feature(tc, primitive=Diff)
+        Feature(tc, primitive=Diff)
 
 
 def test_multi_output_attributes(es):
-    tc = ft.Feature(
+    tc = Feature(
         es["log"].ww["product_id"],
         parent_dataframe_name="sessions",
         primitive=NMostCommon,
@@ -397,14 +411,14 @@ def test_multi_output_attributes(es):
 
 def test_multi_output_index_error(es):
     error_text = "can only access slice of multi-output feature"
-    three_common = ft.Feature(
+    three_common = Feature(
         es["log"].ww["product_id"],
         parent_dataframe_name="sessions",
         primitive=NMostCommon,
     )
 
     with pytest.raises(AssertionError, match=error_text):
-        single = ft.Feature(
+        single = Feature(
             es["log"].ww["product_id"],
             parent_dataframe_name="sessions",
             primitive=NumUnique,
@@ -421,8 +435,10 @@ def test_multi_output_index_error(es):
 
 
 def test_rename(es):
-    feat = ft.Feature(
-        es["log"].ww["id"], parent_dataframe_name="sessions", primitive=Count
+    feat = Feature(
+        es["log"].ww["id"],
+        parent_dataframe_name="sessions",
+        primitive=Count,
     )
     new_name = "session_test"
     new_names = ["session_test"]
@@ -430,7 +446,7 @@ def test_rename(es):
 
 
 def test_rename_multioutput(es):
-    feat = ft.Feature(
+    feat = Feature(
         es["log"].ww["product_id"],
         parent_dataframe_name="customers",
         primitive=NMostCommon(n=2),
@@ -441,33 +457,33 @@ def test_rename_multioutput(es):
 
 
 def test_rename_featureoutputslice(es):
-    multi_output_feat = ft.Feature(
+    multi_output_feat = Feature(
         es["log"].ww["product_id"],
         parent_dataframe_name="customers",
         primitive=NMostCommon(n=2),
     )
-    feat = ft.feature_base.FeatureOutputSlice(multi_output_feat, 0)
+    feat = feature_base.FeatureOutputSlice(multi_output_feat, 0)
     new_name = "session_test"
     new_names = ["session_test"]
     check_rename(feat, new_name, new_names)
 
 
 def test_set_feature_names_wrong_number_of_names(es):
-    feat = ft.Feature(
+    feat = Feature(
         es["log"].ww["product_id"],
         parent_dataframe_name="customers",
         primitive=NMostCommon(n=2),
     )
     new_names = ["col1"]
     error_msg = re.escape(
-        "Number of names provided must match the number of output features: 1 name(s) provided, 2 expected."
+        "Number of names provided must match the number of output features: 1 name(s) provided, 2 expected.",
     )
     with pytest.raises(ValueError, match=error_msg):
         feat.set_feature_names(new_names)
 
 
 def test_set_feature_names_not_unique(es):
-    feat = ft.Feature(
+    feat = Feature(
         es["log"].ww["product_id"],
         parent_dataframe_name="customers",
         primitive=NMostCommon(n=2),
@@ -479,7 +495,7 @@ def test_set_feature_names_not_unique(es):
 
 
 def test_set_feature_names_error_on_single_output_feature(es):
-    feat = ft.Feature(es["sessions"].ww["device_name"], "log")
+    feat = Feature(es["sessions"].ww["device_name"], "log")
     new_names = ["sessions_device"]
     error_msg = "The set_feature_names can only be used on features that have more than one output column."
     with pytest.raises(ValueError, match=error_msg):
@@ -493,14 +509,14 @@ def test_set_feature_names_transform_feature(es):
         return_type = ColumnSchema(semantic_tags={"numeric"})
         number_output_features = 3
 
-    feat = ft.Feature(es["log"].ww["value"], primitive=MultiCumulative)
+    feat = Feature(es["log"].ww["value"], primitive=MultiCumulative)
     new_names = ["cumulative_sum", "cumulative_max", "cumulative_min"]
     feat.set_feature_names(new_names)
     assert feat.get_feature_names() == new_names
 
 
 def test_set_feature_names_aggregation_feature(es):
-    feat = ft.Feature(
+    feat = Feature(
         es["log"].ww["product_id"],
         parent_dataframe_name="customers",
         primitive=NMostCommon(n=2),
@@ -511,7 +527,7 @@ def test_set_feature_names_aggregation_feature(es):
 
 
 def test_renaming_resets_feature_output_names_to_default(es):
-    feat = ft.Feature(
+    feat = Feature(
         es["log"].ww["product_id"],
         parent_dataframe_name="customers",
         primitive=NMostCommon(n=2),
