@@ -53,7 +53,9 @@ def test_base_features_in_list(es):
             value.unique_name(): value.to_dictionary(),
         },
     }
-    expected["primitive_definitions"] = {"0": serialize_primitive(Max())}
+    expected["primitive_definitions"] = {
+        "0": serialize_primitive(max_feature.primitive),
+    }
     expected["feature_definitions"][max_feature.unique_name()]["arguments"][
         "primitive"
     ] = "0"
@@ -93,8 +95,8 @@ def test_multi_output_features(es):
         "feature_definitions": fdict,
     }
     expected["primitive_definitions"] = {
-        "0": serialize_primitive(threecommon),
-        "1": serialize_primitive(num_unique),
+        "0": serialize_primitive(tc.primitive),
+        "1": serialize_primitive(features[2].primitive),
     }
 
     expected["feature_definitions"][flist[0]]["arguments"]["primitive"] = "0"
@@ -127,8 +129,8 @@ def test_base_features_not_in_list(es):
         },
     }
     expected["primitive_definitions"] = {
-        "0": serialize_primitive(max_primitive),
-        "1": serialize_primitive(mult_primitive),
+        "0": serialize_primitive(max_feature.primitive),
+        "1": serialize_primitive(value_x2.primitive),
     }
     expected["feature_definitions"][max_feature.unique_name()]["arguments"][
         "primitive"
@@ -166,7 +168,7 @@ def test_where_feature_dependency(es):
         },
     }
     expected["primitive_definitions"] = {
-        "0": serialize_primitive(max_primitive),
+        "0": serialize_primitive(max_feature.primitive),
     }
     expected["feature_definitions"][max_feature.unique_name()]["arguments"][
         "primitive"
@@ -199,7 +201,9 @@ def test_feature_use_previous_pd_timedelta(es):
             value.unique_name(): value.to_dictionary(),
         },
     }
-    expected["primitive_definitions"] = {"0": serialize_primitive(count_primitive)}
+    expected["primitive_definitions"] = {
+        "0": serialize_primitive(count_feature.primitive),
+    }
     expected["feature_definitions"][count_feature.unique_name()]["arguments"][
         "primitive"
     ] = "0"
@@ -231,7 +235,9 @@ def test_feature_use_previous_pd_dateoffset(es):
             value.unique_name(): value.to_dictionary(),
         },
     }
-    expected["primitive_definitions"] = {"0": serialize_primitive(count_primitive)}
+    expected["primitive_definitions"] = {
+        "0": serialize_primitive(count_feature.primitive),
+    }
     expected["feature_definitions"][count_feature.unique_name()]["arguments"][
         "primitive"
     ] = "0"
@@ -260,7 +266,9 @@ def test_feature_use_previous_pd_dateoffset(es):
             value.unique_name(): value.to_dictionary(),
         },
     }
-    expected["primitive_definitions"] = {"0": serialize_primitive(count_primitive)}
+    expected["primitive_definitions"] = {
+        "0": serialize_primitive(count_feature.primitive),
+    }
     expected["feature_definitions"][count_feature.unique_name()]["arguments"][
         "primitive"
     ] = "0"
