@@ -44,6 +44,7 @@ from featuretools.primitives import (
     RollingMax,
     RollingMean,
     RollingMin,
+    RollingOutlierCount,
     RollingSTD,
     Sum,
     TimeSincePrevious,
@@ -482,6 +483,7 @@ def test_bad_groupby_feature(es):
         RollingMax,
         RollingMean,
         RollingMin,
+        RollingOutlierCount,
         RollingSTD,
     ],
 )
@@ -1115,8 +1117,8 @@ def test_return_types(es):
 def test_checks_primitives_correct_type(es):
     error_text = (
         "Primitive <class \\'featuretools\\.primitives\\.standard\\."
-        "datetime_transform_primitives\\.Hour\\'> in agg_primitives is not an "
-        "aggregation primitive"
+        "transform\\.datetime\\.hour\\.Hour\\'> in "
+        "agg_primitives is not an aggregation primitive"
     )
     with pytest.raises(ValueError, match=error_text):
         DeepFeatureSynthesis(
@@ -1128,7 +1130,7 @@ def test_checks_primitives_correct_type(es):
 
     error_text = (
         "Primitive <class \\'featuretools\\.primitives\\.standard\\."
-        "aggregation_primitives\\.Sum\\'> in trans_primitives "
+        "aggregation\\.sum_primitive\\.Sum\\'> in trans_primitives "
         "is not a transform primitive"
     )
     with pytest.raises(ValueError, match=error_text):
